Name:           oci-fss-utils
Version:        4.11
Release:        %{bld_number}%{?dist}
Summary:        oci fss utils

License:        UPL
Source0:        %{name}-%{version}.tar.gz
Requires:       python3, python3-requests, openssl, jq, json-c, nfs-utils
BuildRequires:  systemd, openssl-devel, json-c-devel, rpmdevtools, libcap-devel, git

%global debug_package %{nil}

%description
oci fss utils

%prep
%setup -q

%pre
cat << @EOF
%include LICENSE.txt
@EOF

%build
%configure --prefix=
%make_build

%install
#printf "====> install $1\n"
#set -x
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/%{_bindir}
%make_install
install -d $RPM_BUILD_ROOT/usr/lib/systemd/system-preset
install -m 644 redhat/10-oci-fss-utils.preset $RPM_BUILD_ROOT/usr/lib/systemd/system-preset

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
/etc/oci-fss-utils.d/LICENSE.txt
/etc/oci-fss-utils.d/THIRD_PARTY_LICENSES.txt
/etc/oci-fss-utils.d/config.json
/etc/oci-fss-utils.d/version-id.txt
/etc/systemd/system/oci-fss-gc.service
/etc/systemd/system/oci-fss-gc.timer
/etc/systemd/system/oci-fss-init.service
/etc/systemd/system/oci-fss-monitor.service
/usr/bin/oci-fss-forwarder
/usr/bin/oci-fss-forwarder-shim.sh
/usr/bin/oci-fss-gc
/usr/bin/oci-fss-monitor
/usr/bin/oci-fss-setup-global.sh
/usr/bin/oci-fss-setup-prefix.sh
/usr/bin/oci-fss-validate-cidr
/usr/lib/systemd/system-preset/10-oci-fss-utils.preset
/usr/sbin/mount.oci-fss
/usr/share/man/man8/mount.oci-fss.8.gz



%post
echo "post ran $(date)" > /etc/oci-fss-utils.d/start.log
systemctl preset oci-fss-gc.timer
systemctl preset oci-fss-init
systemctl preset oci-fss-monitor
if [ "$1" = "1" ]; then
  # initial install
  # systemctl enable doesn't always work in RPM scriptlets for
  # reasons I don't yet understand.  They are often ignored with
  # a message about preset.
  systemctl enable --now oci-fss-gc.timer
  systemctl enable --now oci-fss-init
  systemctl enable --now oci-fss-monitor
elif [ "$1" = "2" ]; then
    # "$1" = "2" means this is an upgrade

    # If there are any old versions of oci-fss-utils...
    find /usr/lib/systemd/system -regextype posix-egrep -regex '/usr/lib/systemd/system/oci-fss-[0-9]+\.service' | while read legacy ; do
        sed -i 's|ExecStart=/opt/oci-fss-utils/oci-fss-forwarder-in-ns.sh|ExecStart=/usr/bin/oci-fss-forwarder-shim.sh|g' $legacy
    done
    systemctl restart oci-fss-monitor
    systemctl restart oci-fss-init
fi
if which firewall-cmd &>/dev/null ; then
    firewall-cmd --permanent --new-zone=oci-fss-utils &>/dev/null
    firewall-cmd --permanent --zone=oci-fss-utils --add-interface x-eth0 &>/dev/null
    firewall-cmd --permanent --zone=oci-fss-utils --add-icmp-block-inversion &>/dev/null
    firewall-cmd --permanent --zone=oci-fss-utils --add-icmp-block=neighbour-solicitation &>/dev/null
    firewall-cmd --permanent --zone=oci-fss-utils --add-icmp-block=neighbour-advertisement &>/dev/null
    firewall-cmd --reload &>/dev/null
    echo Added firewalld oci-fss-utils zone.
fi
oci-fss-setup-prefix.sh



%preun
#printf "====> preun $1\n"
#set -x
if [ "$1" = "0" ]; then
  # uninstall
  if [[ $(oci-fss-gc | tail -n 1) != "live count: 0" ]] ; then
        echo 1>&2
        echo "ERROR: There are still oci-fss-utils mounted filesystems.    Unmount them" 1>&2
        echo "ERROR: before removing the oci-fss-utils package." 1>&2
        echo 1>&2
        exit 1
  fi
  systemctl disable --now oci-fss-gc.timer
  systemctl disable --now oci-fss-init 
  systemctl disable --now oci-fss-monitor
  rm -rf /etc/oci-fss-utils.d/
  rm -rf /tmp/oci-fss-utils.d/
  rm -f /tmp/oci-fss-mount.lck
  if which firewall-cmd &>/dev/null ; then
    firewall-cmd --permanent --delete-zone=oci-fss-utils &>/dev/null
    firewall-cmd --reload &>/dev/null
    echo Removed firewalld oci-fss-utils zone.
  fi
  ip link del x-eth0 &>/dev/null || true
  ip netns del ns1 &>/dev/null || true
elif [ "$1" = "1" ]; then
    # "$1" = "1" means this is an upgrade
    true
fi


%postun
#printf "====> postun $1\n"
#set -x
systemctl daemon-reload


%changelog
* Wed Nov  6 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.11
- Replace build system with autotools
- Add srpm make target

* Mon Sep 30 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.9
- Refuse to uninstall if there are still mounted filesystems.

* Fri Sep 27 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.9
- Make IPv4 first leg from nfs-client to forwarder work again.

* Mon Sep 9 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.8
- fix `mount -a` on OL7

* Wed Aug 21 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.7
- use umask to ensure files created will only set bits -rw-r--r--

* Fri Aug 16 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.7
- Fix resvport behavior and passthrough to mount.nfs
- Fix mounting same mount target to same mount point twice
- Ensure mounting same mount target to two different paths behaves same as mount.nfs
- Ticket 18259

* Tue Aug 13 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.6
- allow gc to remove forwarders as soon as they are found unused
- randomly pick free slots

* Mon Aug 12 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.5
- Share forwarders between mounts to the same mount target

* Fri Aug 2 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.5
- Make oci-fss-monitor restart forwarders on root cert bundle updates

* Fri Aug 2 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.4
- add nfs-utils to rpm dependencies

* Wed Jul 31 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.4
- split up ERR from HUP and RDHUP
- remove duplicate listen socket on 2049
- remove duplicates from wildcards in config.json
 
* Tue Jul 30 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.4
- add firewalld oci-fss-utils zone to allow ICMPv6 neigh discovery on x-eth0
- add explicit rpm dependency to python3-requests

* Wed Jul 24 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.3
- fix incorrect dates in RPM changelog
- fix some other minor rpm build warnings
- fixes in how certificate bundle is generated and validated

* Fri Apr 26 2024 Reuben Hawkins <reuben.hawkins@oracle.com> 4.1-1
- IPv6 support
- single iface (x-eth0)

* Mon Apr 05 2021 Hualiang Xu <hualiang.xu@oracle.com> 1.0-20
- rotate root for oc5/6/7

* Mon Apr 05 2021 Hualiang Xu <hualiang.xu@oracle.com> 1.0-19
- add gov8 & gov9 certs

* Mon Aug 31 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-18
- move the ip forwarding rule to FORWARD chain

* Mon Aug 17 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-17
- don't flush the security rules
- potential bug fix for verizon

* Tue Aug 04 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-16
- auto clean veth

* Fri Feb 28 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-15
- resvport for 111 (portmapper)

* Fri Feb 28 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-14
- oci-fss-config util and the ability to mount with vnic

* Thu Feb 13 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-13
- drop capability
- dump mount target many times instead of network namespace

* Thu Feb 13 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-12
- add gov root ca

* Thu Feb 13 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-11
- check_call for umount

* Thu Feb 13 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-10
- relax gc cycle from 1 minute to 1 hour
- replace /proce/mounts with df

* Thu Feb 13 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-9
- back out the privilege code change

* Wed Feb 12 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-8
- pre bind resvport before dropping the privilege

* Fri Feb 07 2020 Hualiang Xu <hualiang.xu@oracle.com> 1.0-7
- don't drop privilege, we need root for resvport

